CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
88 lines
2.2 KiB
Plaintext
88 lines
2.2 KiB
Plaintext
/*
|
|
* Copyright (c) Advanced Micro Devices, Inc., or its affiliates.
|
|
*
|
|
* SPDX-License-Identifier: MIT
|
|
*/
|
|
|
|
#include <stdio.h>
|
|
#include <cuda_runtime.h>
|
|
|
|
#define CHECK(cmd) \
|
|
{\
|
|
cudaError_t error = cmd;\
|
|
if (error != cudaSuccess) { \
|
|
fprintf(stderr, "error: '%s'(%d) at %s:%d\n", cudaGetErrorString(error), error,__FILE__, __LINE__); \
|
|
exit(EXIT_FAILURE);\
|
|
}\
|
|
}
|
|
|
|
|
|
/*
|
|
* Square each element in the array A and write to array C.
|
|
*/
|
|
template <typename T>
|
|
__global__ void
|
|
vector_square(T *C_d, T *A_d, size_t N)
|
|
{
|
|
size_t offset = (blockIdx.x * blockDim.x + threadIdx.x);
|
|
size_t stride = blockDim.x * gridDim.x ;
|
|
|
|
for (size_t i=offset; i<N; i+=stride) {
|
|
C_d[i] = A_d[i] * A_d[i];
|
|
}
|
|
}
|
|
|
|
|
|
int main(int argc, char *argv[])
|
|
{
|
|
float *A_d, *C_d;
|
|
float *A_h, *C_h;
|
|
size_t N = 1000000;
|
|
size_t Nbytes = N * sizeof(float);
|
|
|
|
cudaDeviceProp props;
|
|
CHECK(cudaGetDeviceProperties(&props, 0/*deviceID*/));
|
|
printf ("info: running on device %s\n", props.name);
|
|
|
|
printf ("info: allocate host mem (%6.2f MB)\n", 2*Nbytes/1024.0/1024.0);
|
|
A_h = (float*)malloc(Nbytes);
|
|
CHECK(A_h == 0 ? cudaErrorMemoryAllocation : cudaSuccess );
|
|
C_h = (float*)malloc(Nbytes);
|
|
CHECK(C_h == 0 ? cudaErrorMemoryAllocation : cudaSuccess );
|
|
// Fill with Phi + i
|
|
for (size_t i=0; i<N; i++)
|
|
{
|
|
A_h[i] = 1.618f + i;
|
|
}
|
|
|
|
printf ("info: allocate device mem (%6.2f MB)\n", 2*Nbytes/1024.0/1024.0);
|
|
CHECK(cudaMalloc(&A_d, Nbytes));
|
|
CHECK(cudaMalloc(&C_d, Nbytes));
|
|
|
|
|
|
printf ("info: copy Host2Device\n");
|
|
CHECK ( cudaMemcpy(A_d, A_h, Nbytes, cudaMemcpyHostToDevice));
|
|
|
|
const unsigned blocks = 512;
|
|
const unsigned threadsPerBlock = 256;
|
|
|
|
printf ("info: launch 'vector_square' kernel\n");
|
|
vector_square <<<blocks, threadsPerBlock>>> (C_d, A_d, N);
|
|
|
|
printf ("info: copy Device2Host\n");
|
|
CHECK ( cudaMemcpy(C_h, C_d, Nbytes, cudaMemcpyDeviceToHost));
|
|
|
|
printf ("info: check result\n");
|
|
for (size_t i=0; i<N; i++) {
|
|
if (C_h[i] != A_h[i] * A_h[i]) {
|
|
CHECK(cudaErrorUnknown);
|
|
}
|
|
}
|
|
|
|
CHECK ( cudaFree(A_d));
|
|
CHECK ( cudaFree(C_d));
|
|
free(A_h);
|
|
free(C_h);
|
|
printf ("PASSED!\n");
|
|
}
|